@@ -58,7 +58,7 @@ use Carp qw(croak);
 use WebService::Yahoo::BOSS::Response;
 
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 my $Ug = Data::UUID->new;
 
@@ -68,9 +68,11 @@ $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 =head2 new
 
     $boss = WebService::Yahoo::BOSS->new(
+
         # required
         ckey => $ckey,
         csecret => $csecret,
+
         # optional
         url => 'http://yboss.yahooapis.com',
         ua => LWP::UserAgent->new(...),
@@ -96,6 +98,11 @@ has 'ua' => (
     }
 );
 
+# last HTTP::Response e.g. to enable introspection of error details
+has 'http_response' => (
+    is => 'rw'
+);
+
 
 sub _create_boss_request {
     my ($self, $api_path, $args) = @_;
@@ -123,6 +130,7 @@ sub _perform_boss_request {
     my ($self, $request) = @_;
 
     my $res = $self->ua->get( $request->to_url );
+    $self->http_response($res);
     unless ( $res->is_success ) {
         die sprintf "%s requesting %s: %s",
             $res->status_line, $request->to_url, Dumper($res);
@@ -202,9 +210,9 @@ sub PlaceFinder {
 
 =head1 SEE ALSO
 
- http://developer.yahoo.com/search/boss/boss_api_guide
+L<http://developer.yahoo.com/search/boss/boss_api_guide>
 
- L<Google::Search>
+L<Google::Search>
 
 =head1 AUTHOR
 
